/*
 * MIDIInfo.h - Voicing and Effects MIDI Information for the SAM2195 MIDI/Synth chip
 *
 * Written by: Craig A. Lindley
 * Version: 1.0
 * Last Update: 09/10/2014
 *
 * Copyright (c) 2014 Craig A. Lindley
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 * the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef MIDIINFO_H
#define MIDIINFO_H

// MIDI defines
#define NUMBER_OF_MIDI_CHANNELS 16

#define MIDI_MAX_VOLUME   127
#define MIDI_MIN_VOLUME     0

#define MIDI_BANK0          0
#define MIDI_BANK1        127

// Define a new datatype
typedef struct {
    char *name;
    int value;
} 
NAMED_VALUE;

NAMED_VALUE DRUM_TYPES [] = {
    "Standard Set",    0,
    "Power Set",      16,
    "Brush Set",      40,
    "Orchestral Set", 48,
    "CM-64/32 Set",  127  
};

#define NUMBER_OF_DRUMSETS (sizeof(DRUM_TYPES) / sizeof(NAMED_VALUE))

#define NUMBER_OF_BANK_VOICES 128

// Define BANK 0 Voices
char * BANK0_VOICES [NUMBER_OF_BANK_VOICES] = {
    "Grand Piano",
    "Brght Piano",
    "E Gnd Piano",
    "Honky Piano",
    "E Piano 1", 
    "E Piano 2",
    "Harpsichord",
    "Clavi",
    "Celesta",
    "Glckenspiel",
    "Music Box",
    "Vibraphone",
    "Marimba",
    "Xylophone",
    "Tubulr Bells",
    "Santur",
    "DB Organ", 
    "Percus Organ",
    "Rock Organ",
    "Church Organ",
    "Reed Organ",
    "Accordion",
    "Harmonica",
    "T Accordion",
    "AG Nylon",
    "AG Steel",
    "EG Jazz",
    "EG Clean",
    "EG Muted",
    "OverD Guitar",
    "Dist Guitar",
    "Harm Guitar",
    "Acoust Bass",
    "Finger Bass",
    "Picked Bass",
    "NoFret Bass",
    "Slap Bass 1",
    "Slap Bass 2",
    "Synth Bass 1",
    "Synth Bass 2",
    "Violin",
    "Viola",
    "Cello",
    "Contrabass",
    "Trem Strings",
    "Pizz Strings",
    "Harp",
    "Timpani",
    "String En 1",
    "String En 2",
    "Syn Strngs 1",
    "Syn Strngs 2",
    "Choir Aahs",
    "Voice Oohs",
    "Synth Voice",
    "Orch Hit",
    "Trumpet",
    "Trombone",
    "Tuba", 
    "M Trumpet",
    "French Horn",
    "Brass Sect",
    "Syn Brass 1",
    "Syn Brass 2",
    "Soprano Sax",
    "Alto Sax",
    "Tenor Sax",
    "Baritone Sax",
    "Oboe",
    "English Horn",
    "Bassoon",
    "Clarinet",
    "Piccolo",
    "Flute",
    "Recorder",
    "Pan Flute",
    "Blown Bottle",
    "Shakuhachi",
    "Whistle",
    "Ocarina",
    "Lead Square",
    "Lead Saw",
    "Lead Caliope",
    "Lead Chiff",
    "Lead Charang",
    "Lead Voice",
    "Lead Fifths",
    "Lead BassLd",
    "Pad Fantasia",
    "Pad Warm",
    "Pad Polysyn",
    "Pad Choir",
    "Pad Bowed",
    "Pad Metallic",
    "Pad Halo",
    "Pad Sweep",
    "FX Rain",
    "FX Soundtrak",
    "FX Crystal",
    "FX Atmos",
    "FX Bright",
    "FX Goblins",
    "FX Echoes",
    "FX Sci_fi",
    "Sitar",
    "Banjo",
    "Shamisen",
    "Koto",
    "Kalimba",
    "Bagpipe",
    "Fiddle",
    "Shanai",
    "Tinkle Bell",
    "Agogo",
    "Steel Drums",
    "Woodblock",
    "Taiko Drum",
    "Melodic Tom",
    "Synth Drum",
    "Rev Cymbal",
    "Fret Noise",
    "Breath Noise",
    "Seashore",
    "Bird Tweet",
    "Telephone",
    "Helicopter",
    "Applause",
    "Gunshot"
};

// Define BANK 1 Voices
char * BANK1_VOICES [NUMBER_OF_BANK_VOICES] = {
    "Piano 1",
    "Piano 2",
    "Piano 3",
    "Detuned EP 1",
    "E Piano 1",
    "E Piano 2",
    "Detuned EP 2",
    "Honky-Tonk",
    "Organ 1",
    "Organ 2",
    "Organ 3",
    "Detuned Or 1",
    "Church Org2",
    "Church Org",
    "Church Org",
    "Accordion",
    "Harpsichord",
    "Coupled Hps",
    "Coupled Hps",
    "Clav",
    "Clav",
    "Clav",
    "Celesta",
    "Celesta",
    "Syn Brass 1",
    "Syn Brass 2",
    "Syn Brass 3",
    "Syn Brass 4",
    "Syn Bass 1",
    "Syn Bass 2",
    "Syn Bass 3",
    "Syn Bass 4",
    "Fantasia",
    "Syn Caliope",
    "Choir Aahs",
    "Bowed Glass",
    "Soundtrack",
    "Atmosphere",
    "Crystal",
    "BagPipe",
    "Tinkle Bell",
    "Ice Rain",
    "Oboe",
    "Pan Flute",
    "Saw Wave",
    "Charang",
    "Tubulr Bells",
    "Square Wave",
    "Strings",
    "Trem Strings",
    "Slow Strings",
    "Pizz Strings",
    "Violin",
    "Viola",
    "Cello",
    "Cello",
    "Contrabass",
    "Harp",
    "Harp",
    "Nylon Guitar",
    "Steel Guitar",
    "Chorus Guitr",
    "Funk Guitar",
    "Sitar",
    "Acoust Bass",
    "Finger Bass",
    "Picked Bass",
    "NoFret Bass",
    "Slap Bass 1",
    "Slap Bass 2",
    "NoFret Bass",
    "NoFret Bass",
    "Flute",
    "Flute",
    "Piccolo",
    "Piccolo",
    "Recorder",
    "Pan Flute",
    "Soprano Sax",
    "Alto Sax",
    "Tenor Sax",
    "Baritone Sax",
    "Clarinet",
    "Clarinet",
    "Oboe",
    "English Horn",
    "Bassoon",
    "Harmonica",
    "Trumped",
    "Mute Trumpet",
    "Trombone",
    "Trombone",
    "FrenchHorn",
    "FrenchHorn",
    "Tuba",
    "Brass",
    "Brass 2",
    "Vibraphone",
    "Vibraphone",
    "Kalimba",
    "Tinkle Bell",
    "Glockenspiel",
    "Tubular Bell",
    "Xylophone",
    "Marimba",
    "Koto",
    "Taisho Koto",
    "Shakuhachi",
    "Whistle",
    "Whistle",
    "Bottle Blow",
    "Pan Flute",
    "Timpani",
    "Melo Tom",
    "Melo Tom",
    "Synth Drum",
    "Synth Drum",
    "Taiko",
    "Taiko",
    "Rev Cymbol",
    "Castanets",
    "Tinkle Bell",
    "Orch Hit",
    "Telephone",
    "Bird",
    "Helicopter",
    "Bowed Glass",
    "Ice Rain"
};

// Define reverb types
char * REVERB_TYPES [] = {
    "ROOM1", "ROOM2", "ROOM3", "HALL1", "HALL2", "PLATE", "DELAY", "PANDELAY"
};

#define NUMBER_OF_REVERBS (sizeof(REVERB_TYPES) / sizeof(char *))

// Define chorus typtes
char * CHORUS_TYPES [] = {
    "CHORUS1", "CHORUS2", "CHORUS3", "CHORUS4", "FEEDBACK", "FLANGER", "SHORTDEL", "FBDELAY"
};

#define NUMBER_OF_CHORUSES (sizeof(CHORUS_TYPES) / sizeof(char *))

#endif


