/*
 * SAM2195.h - Header file for Interface Functions for SAM2195 MIDI Synth Chip
 *
 * Based upon Modern Device Fluxamasynth Arduino Library
 * but using hardware UART instead of NewSoftSerial.
 *
 * Written by: Craig A. Lindley
 * Version: 1.0
 * Last Update: 09/10/2014
 *
 * Copyright (c) 2014 Craig A. Lindley
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 * the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

#include "Arduino.h"

#ifndef SAM2195_H
#define SAM2195_H

// Write a byte to the synth's serial port
int write (byte b);

void midiReset();
void gmReset();
void gsReset();

void selectAndInitializeSerialPort (int portNumber);
void noteOn (byte channel, byte pitch, byte velocity);
void noteOff (byte channel, byte pitch);
void controllerChange (byte channel, byte type, byte value);
void programChange (byte bank, byte channel, byte value);
void drumSetChange (byte set);
void pitchBend (byte channel, int value);
void pitchBendRange (byte channel, byte value);
void setChannelVolume (byte channel, byte level);
void setChannelPan (int channel, int value);
void setMasterVolume (byte level);

// Effects
void setReverb (byte channel, byte program, byte level, byte feedback);
void setChorus (byte channel, byte program, byte level, byte feedback, byte chorusDelay);
void setModulation(byte channel, byte depth, byte rate);
void setPortamento(byte channel, boolean on, byte time);

#endif
